# MD005 - List Indentation

This rule enforces consistent indentation for list items at each level.

## Description

Lists in Markdown should have consistent indentation at each level. This means:

- All list items at the same level should have the same indentation
- Nested list items should be indented consistently relative to their parent
- The rule applies to both ordered and unordered lists
- Mixed list types (ordered and unordered) at the same level should have the same indentation

## Configuration

This rule has no configuration options. It enforces:

- 0 spaces for top-level list items
- 2 spaces per level for nested items (both ordered and unordered lists)

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
* Item 1
* Item 2
  * Nested 1
  * Nested 2
* Item 3

1. Item 1
2. Item 2
   1. Nested 1
   2. Nested 2
3. Item 3

* Item 1
  * Nested 1
    * Deep nested
  * Back to level 2
* Item 3

# Mixed list types at the same level have the same indentation
* Unordered item
* Another unordered item
1. Ordered item at same level
2. Another ordered item
  * Nested unordered under ordered
  * Same indentation for siblings
  1. Nested ordered under ordered
  2. Same indentation for siblings
```

### Invalid

```markdown
* Item 1
 * Item 2 (wrong indentation - 1 space instead of 0 or 2)
   * Nested 1

* Item 1
  * Nested 1
   * Nested 2 (inconsistent with sibling - 3 spaces instead of 2)
* Item 2

* Item 1
   * Level 2 (wrong indentation - 3 spaces instead of 2)
      * Level 3 (wrong indentation - 6 spaces instead of 4)

# Inconsistent indentation for mixed list types
* Unordered item
* Another unordered item
 1. Ordered item with wrong indentation (1 space)
 2. Another ordered item
```

### Fixed

```markdown
* Item 1
* Item 2
  * Nested 1

* Item 1
  * Nested 1
  * Nested 2
* Item 2

* Item 1
  * Level 2
    * Level 3

# Consistent indentation for mixed list types
* Unordered item
* Another unordered item
1. Ordered item at same level
2. Another ordered item
```
<!-- markdownlint-enable -->

## Related Rules

- [MD004](md004.md) - Unordered list style
- [MD007](md007.md) - Unordered list indentation
