# MD019 - No Multiple Spaces After Hash in ATX Heading

## Description

This rule ensures that there is only one space between the hash signs (#) and the heading text in ATX-style headings.
Multiple spaces can cause inconsistent rendering across different Markdown processors.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
# Heading 1
## Heading 2
### Heading 3
#### Heading 4
##### Heading 5
###### Heading 6
```

### Invalid

```markdown
#  Heading 1 (two spaces)
##  Heading 2 (two spaces)
###   Heading 3 (three spaces)
####    Heading 4 (four spaces)
#####     Heading 5 (five spaces)
######      Heading 6 (six spaces)
```

### Fixed

```markdown
# Heading 1
## Heading 2
### Heading 3
#### Heading 4
##### Heading 5
###### Heading 6
```
<!-- markdownlint-enable -->

## Special Cases

- This rule only applies to ATX-style headings (those that start with hash signs)
- It does not apply to closed ATX headings (those with hash signs at both the beginning and end)
- It does not apply to setext-style headings (those underlined with = or -)
- Empty headings (just hash signs with no text) are not affected

## Related Rules

- [MD018 - No missing space in ATX heading](md018.md): Ensures there is a space after the hash signs
- [MD020 - No missing space in closed ATX heading](md020.md): Similar rule for closed ATX headings
- [MD021 - No multiple spaces in closed ATX heading](md021.md): Ensures consistent spacing in closed ATX headings
