# MD024 - Multiple Headings with the Same Content

## Description

This rule ensures that a document doesn't have multiple headings with the same content.  
Duplicate headings can confuse readers and cause issues with generated tables of contents.

By default, this rule considers all headings in the document, but it can be configured to  
only check for duplicates within the same section level.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
# Heading

## First Section

Some content here.

## Second Section

More content here.
```

### Invalid

```markdown
# Heading

## Section

Some content here.

## Section

More content here.
```

### Fixed

```markdown
# Heading

## First Section

Some content here.

## Second Section

More content here.
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `allow*different*nesting`: When set to `true`, headings with the same content are allowed  
if they are not at the same level in the document hierarchy. Default is `false`.
- `siblings_only`: When set to `true`, only sibling headings (headings at the same level in  
the document hierarchy) are checked for duplicates. Default is `false`.

## Special Cases

- This rule does not apply to headings within code blocks
- The comparison is case-sensitive by default
- The rule considers the entire heading content, including any formatting

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD025 - Single title/h1](md025.md): Ensures there's only one top-level heading
