# MD025 - Single Title/H1

## Description

This rule ensures that a document has only one top-level heading (H1). Having multiple H1 headings can confuse readers and cause issues with document structure and navigation.

By default, this rule checks for the presence of multiple H1 headings in the main content. It can also be configured to check for a specific heading level.

## Configuration

This rule has the following configuration options:

- `level`: The heading level that should be unique. Default is `1`.
- `front*matter*title`: The name of the front matter title field. Default is `title`.

## Examples

### Valid

```markdown
# Document Title

## Section 1

Content here.

## Section 2

More content here.
```

### Invalid

```markdown
# First Title

Content here.

# Second Title

More content here.
```

### Fixed

```markdown
# Document Title

## First Section

Content here.

## Second Section

More content here.
```

## Special Cases

- This rule does not apply to headings within code blocks
- When `front*matter*title` is set, the rule will consider the title in front matter as the first H1
- If a document has front matter with a title and also an H1 in the content, it will trigger a warning

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD024 - Multiple headings with the same content](md024.md): Prevents duplicate heading text
