# MD026 - No Trailing Punctuation in Headings

## Description

This rule ensures that headings do not end with punctuation characters. Trailing punctuation in headings can be visually distracting and is generally considered poor style in technical documentation.

By default, this rule checks for the following punctuation characters: `.,;:!?`. The list of punctuation characters can be customized through configuration.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
# Introduction

## Project Overview

### How to Install
```

### Invalid

```markdown
# Introduction!

## Project Overview?

### How to Install.
```

### Fixed

```markdown
# Introduction

## Project Overview

### How to Install
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `punctuation`: A string containing the punctuation characters to check for at the end of headings. Default is `.,;:!?`.

## Special Cases

- This rule does not apply to headings within code blocks
- The rule only checks the last character of the heading
- Punctuation characters that are part of a word (like in "Node.js") are not affected by this rule
- The rule does not affect punctuation in the middle of a heading

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD025 - Single title/h1](md025.md): Ensures there's only one top-level heading
