# MD035 - Horizontal Rule Style

## Description

This rule ensures that horizontal rules (also known as thematic breaks) have a consistent style throughout  
a document. Horizontal rules can be created using three or more of the following characters: hyphens (`-`),  
asterisks (`*`), or underscores (`_`).

By default, the rule enforces the use of three hyphens (`---`) for horizontal rules.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
Text before the horizontal rule.

---

Text after the horizontal rule.
```

### Invalid

```markdown
Text before the first horizontal rule.

***

Text between horizontal rules.

___

Text after the second horizontal rule.
```

### Fixed

```markdown
Text before the first horizontal rule.

---

Text between horizontal rules.

---

Text after the second horizontal rule.
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `style`: The style of horizontal rule to enforce. Default is `"---"`.

Valid styles include:
- `"---"`: Three hyphens
- `"***"`: Three asterisks
- `"___"`: Three underscores
- Or any other consistent pattern like `"- - -"` or `"* * *"`

## Special Cases

- This rule only applies to horizontal rules (three or more hyphens, asterisks, or underscores)
- It does not apply to other Markdown elements that use similar syntax
- The rule checks for consistency, not correctness (all valid horizontal rule styles are acceptable)
- Spaces between the characters are preserved when fixing

## Related Rules

- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD012 - Multiple consecutive blank lines](md012.md): Ensures proper spacing between content
- [MD022 - Headings should be surrounded by blank lines](md022.md): Ensures proper spacing around headings
