# MD036 - No Emphasis as Heading

## Description

This rule ensures that emphasis (bold or italic) is not used as a substitute for proper headings.  
Using emphasis to create headings can lead to inconsistent document structure and accessibility issues.

Proper headings provide better document structure, are more accessible, and enable automatic  
generation of tables of contents.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
# This is a proper heading

## This is another proper heading

This is a paragraph with **bold** and *italic* text within it.
```

### Invalid

```markdown
**This is not a proper heading**

*This is not a proper heading either*

***This is definitely not a proper heading***
```

### Fixed

```markdown
## This is not a proper heading

## This is not a proper heading either

### This is definitely not a proper heading
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `punctuation`: A string containing the punctuation characters that are allowed at the end of emphasized text without triggering this rule. Default is `".,;:!?"`.

## Special Cases

- This rule only applies to emphasis that appears alone on a line
- Emphasis within other content is not affected
- Both single emphasis (*italic*) and double emphasis (**bold**) are checked
- Triple emphasis (***bold italic***) is also checked
- The rule can be configured to allow certain punctuation at the end of emphasized text

## Related Rules

- [MD001 - Heading increment](md001.md): Ensures heading levels increment by one level at a time
- [MD003 - Heading style](md003.md): Ensures consistent heading style
- [MD018 - No missing space in ATX heading](md018.md): Ensures proper spacing in headings
